==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/GetVirtualApplianceSitePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.GetVirtualApplianceSitePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property networkVirtualApplianceName The name of the Network Virtual Appliance.
 * @property resourceGroupName The name of the resource group.
 * @property siteName The name of the site.
 */
public data class GetVirtualApplianceSitePlainArgs(
    public val networkVirtualApplianceName: String,
    public val resourceGroupName: String,
    public val siteName: String,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.GetVirtualApplianceSitePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.GetVirtualApplianceSitePlainArgs =
        com.pulumi.azurenative.network.inputs.GetVirtualApplianceSitePlainArgs.builder()
            .networkVirtualApplianceName(networkVirtualApplianceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .siteName(siteName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetVirtualApplianceSitePlainArgs].
 */
@PulumiTagMarker
public class GetVirtualApplianceSitePlainArgsBuilder internal constructor() {
    private var networkVirtualApplianceName: String? = null

    private var resourceGroupName: String? = null

    private var siteName: String? = null

    /**
     * @param value The name of the Network Virtual Appliance.
     */
    @JvmName("qfnpojtilhvgodvk")
    public suspend fun networkVirtualApplianceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.networkVirtualApplianceName = mapped
    }

    /**
     * @param value The name of the resource group.
     */
    @JvmName("btbhmtwbiqlpaiqb")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the site.
     */
    @JvmName("hlutjeyihgmieulo")
    public suspend fun siteName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.siteName = mapped
    }

    internal fun build(): GetVirtualApplianceSitePlainArgs = GetVirtualApplianceSitePlainArgs(
        networkVirtualApplianceName = networkVirtualApplianceName ?: throw
            PulumiNullFieldException("networkVirtualApplianceName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        siteName = siteName ?: throw PulumiNullFieldException("siteName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/GetVirtualApplianceSitePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.GetVirtualApplianceSitePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property networkVirtualApplianceName The name of the Network Virtual Appliance.
 * @property resourceGroupName The name of the resource group.
 * @property siteName The name of the site.
 */
public data class GetVirtualApplianceSitePlainArgs(
    public val networkVirtualApplianceName: String,
    public val resourceGroupName: String,
    public val siteName: String,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.GetVirtualApplianceSitePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.GetVirtualApplianceSitePlainArgs =
        com.pulumi.azurenative.network.inputs.GetVirtualApplianceSitePlainArgs.builder()
            .networkVirtualApplianceName(networkVirtualApplianceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .siteName(siteName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetVirtualApplianceSitePlainArgs].
 */
@PulumiTagMarker
public class GetVirtualApplianceSitePlainArgsBuilder internal constructor() {
    private var networkVirtualApplianceName: String? = null

    private var resourceGroupName: String? = null

    private var siteName: String? = null

    /**
     * @param value The name of the Network Virtual Appliance.
     */
    @JvmName("qmewnqrhgmdadjrw")
    public suspend fun networkVirtualApplianceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.networkVirtualApplianceName = mapped
    }

    /**
     * @param value The name of the resource group.
     */
    @JvmName("ldqvwshfavwsbhvs")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the site.
     */
    @JvmName("swbyvegawbnxpnyn")
    public suspend fun siteName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.siteName = mapped
    }

    internal fun build(): GetVirtualApplianceSitePlainArgs = GetVirtualApplianceSitePlainArgs(
        networkVirtualApplianceName = networkVirtualApplianceName ?: throw
            PulumiNullFieldException("networkVirtualApplianceName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        siteName = siteName ?: throw PulumiNullFieldException("siteName"),
    )
}
